resources

package
v0.3.9-beta.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 17, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the resources type in the database.
	Label = "resources"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldCreatedBy holds the string denoting the created_by field in the database.
	FieldCreatedBy = "created_by"
	// FieldUpdatedBy holds the string denoting the updated_by field in the database.
	FieldUpdatedBy = "updated_by"
	// FieldParentID holds the string denoting the parent_id field in the database.
	FieldParentID = "parent_id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldSortOrder holds the string denoting the sort_order field in the database.
	FieldSortOrder = "sort_order"
	// FieldResourceType holds the string denoting the resource_type field in the database.
	FieldResourceType = "resource_type"
	// FieldResourceScope holds the string denoting the resource_scope field in the database.
	FieldResourceScope = "resource_scope"
	// FieldEnabled holds the string denoting the enabled field in the database.
	FieldEnabled = "enabled"
	// FieldHidden holds the string denoting the hidden field in the database.
	FieldHidden = "hidden"
	// FieldHideChildren holds the string denoting the hide_children field in the database.
	FieldHideChildren = "hide_children"
	// FieldPath holds the string denoting the path field in the database.
	FieldPath = "path"
	// FieldIcon holds the string denoting the icon field in the database.
	FieldIcon = "icon"
	// FieldComponent holds the string denoting the component field in the database.
	FieldComponent = "component"
	// FieldDescription holds the string denoting the description field in the database.
	FieldDescription = "description"
	// EdgeLionPermissions holds the string denoting the lion_permissions edge name in mutations.
	EdgeLionPermissions = "lion_permissions"
	// Table holds the table name of the resources in the database.
	Table = "lion_resources"
	// LionPermissionsTable is the table that holds the lion_permissions relation/edge.
	LionPermissionsTable = "lion_permissions"
	// LionPermissionsInverseTable is the table name for the Permissions entity.
	// It exists in this package in order to avoid circular dependency with the "permissions" package.
	LionPermissionsInverseTable = "lion_permissions"
	// LionPermissionsColumn is the table column denoting the lion_permissions relation/edge.
	LionPermissionsColumn = "resource_id"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultCreatedBy holds the default value on creation for the "created_by" field.
	DefaultCreatedBy int64
	// DefaultUpdatedBy holds the default value on creation for the "updated_by" field.
	DefaultUpdatedBy int64
	// DefaultParentID holds the default value on creation for the "parent_id" field.
	DefaultParentID int
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// DefaultSortOrder holds the default value on creation for the "sort_order" field.
	DefaultSortOrder int
	// DefaultResourceType holds the default value on creation for the "resource_type" field.
	DefaultResourceType int
	// DefaultResourceScope holds the default value on creation for the "resource_scope" field.
	DefaultResourceScope int
	// DefaultEnabled holds the default value on creation for the "enabled" field.
	DefaultEnabled bool
	// DefaultHidden holds the default value on creation for the "hidden" field.
	DefaultHidden bool
	// DefaultHideChildren holds the default value on creation for the "hide_children" field.
	DefaultHideChildren bool
	// DefaultPath holds the default value on creation for the "path" field.
	DefaultPath string
	// PathValidator is a validator for the "path" field. It is called by the builders before save.
	PathValidator func(string) error
	// DefaultIcon holds the default value on creation for the "icon" field.
	DefaultIcon string
	// IconValidator is a validator for the "icon" field. It is called by the builders before save.
	IconValidator func(string) error
	// DefaultComponent holds the default value on creation for the "component" field.
	DefaultComponent string
	// ComponentValidator is a validator for the "component" field. It is called by the builders before save.
	ComponentValidator func(string) error
	// DefaultDescription holds the default value on creation for the "description" field.
	DefaultDescription string
)

Columns holds all SQL columns for resources fields.

Functions

func And

func And(predicates ...predicate.Resources) predicate.Resources

And groups predicates with the AND operator between them.

func Component

func Component(v string) predicate.Resources

Component applies equality check predicate on the "component" field. It's identical to ComponentEQ.

func ComponentContains

func ComponentContains(v string) predicate.Resources

ComponentContains applies the Contains predicate on the "component" field.

func ComponentContainsFold

func ComponentContainsFold(v string) predicate.Resources

ComponentContainsFold applies the ContainsFold predicate on the "component" field.

func ComponentEQ

func ComponentEQ(v string) predicate.Resources

ComponentEQ applies the EQ predicate on the "component" field.

func ComponentEqualFold

func ComponentEqualFold(v string) predicate.Resources

ComponentEqualFold applies the EqualFold predicate on the "component" field.

func ComponentGT

func ComponentGT(v string) predicate.Resources

ComponentGT applies the GT predicate on the "component" field.

func ComponentGTE

func ComponentGTE(v string) predicate.Resources

ComponentGTE applies the GTE predicate on the "component" field.

func ComponentHasPrefix

func ComponentHasPrefix(v string) predicate.Resources

ComponentHasPrefix applies the HasPrefix predicate on the "component" field.

func ComponentHasSuffix

func ComponentHasSuffix(v string) predicate.Resources

ComponentHasSuffix applies the HasSuffix predicate on the "component" field.

func ComponentIn

func ComponentIn(vs ...string) predicate.Resources

ComponentIn applies the In predicate on the "component" field.

func ComponentLT

func ComponentLT(v string) predicate.Resources

ComponentLT applies the LT predicate on the "component" field.

func ComponentLTE

func ComponentLTE(v string) predicate.Resources

ComponentLTE applies the LTE predicate on the "component" field.

func ComponentNEQ

func ComponentNEQ(v string) predicate.Resources

ComponentNEQ applies the NEQ predicate on the "component" field.

func ComponentNotIn

func ComponentNotIn(vs ...string) predicate.Resources

ComponentNotIn applies the NotIn predicate on the "component" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Resources

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Resources

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Resources

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Resources

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Resources

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Resources

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Resources

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Resources

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Resources

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedBy

func CreatedBy(v int64) predicate.Resources

CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.

func CreatedByEQ

func CreatedByEQ(v int64) predicate.Resources

CreatedByEQ applies the EQ predicate on the "created_by" field.

func CreatedByGT

func CreatedByGT(v int64) predicate.Resources

CreatedByGT applies the GT predicate on the "created_by" field.

func CreatedByGTE

func CreatedByGTE(v int64) predicate.Resources

CreatedByGTE applies the GTE predicate on the "created_by" field.

func CreatedByIn

func CreatedByIn(vs ...int64) predicate.Resources

CreatedByIn applies the In predicate on the "created_by" field.

func CreatedByIsNil

func CreatedByIsNil() predicate.Resources

CreatedByIsNil applies the IsNil predicate on the "created_by" field.

func CreatedByLT

func CreatedByLT(v int64) predicate.Resources

CreatedByLT applies the LT predicate on the "created_by" field.

func CreatedByLTE

func CreatedByLTE(v int64) predicate.Resources

CreatedByLTE applies the LTE predicate on the "created_by" field.

func CreatedByNEQ

func CreatedByNEQ(v int64) predicate.Resources

CreatedByNEQ applies the NEQ predicate on the "created_by" field.

func CreatedByNotIn

func CreatedByNotIn(vs ...int64) predicate.Resources

CreatedByNotIn applies the NotIn predicate on the "created_by" field.

func CreatedByNotNil

func CreatedByNotNil() predicate.Resources

CreatedByNotNil applies the NotNil predicate on the "created_by" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.Resources

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.Resources

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.Resources

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.Resources

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.Resources

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.Resources

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.Resources

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.Resources

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.Resources

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.Resources

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.Resources

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func Description

func Description(v string) predicate.Resources

Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.

func DescriptionContains

func DescriptionContains(v string) predicate.Resources

DescriptionContains applies the Contains predicate on the "description" field.

func DescriptionContainsFold

func DescriptionContainsFold(v string) predicate.Resources

DescriptionContainsFold applies the ContainsFold predicate on the "description" field.

func DescriptionEQ

func DescriptionEQ(v string) predicate.Resources

DescriptionEQ applies the EQ predicate on the "description" field.

func DescriptionEqualFold

func DescriptionEqualFold(v string) predicate.Resources

DescriptionEqualFold applies the EqualFold predicate on the "description" field.

func DescriptionGT

func DescriptionGT(v string) predicate.Resources

DescriptionGT applies the GT predicate on the "description" field.

func DescriptionGTE

func DescriptionGTE(v string) predicate.Resources

DescriptionGTE applies the GTE predicate on the "description" field.

func DescriptionHasPrefix

func DescriptionHasPrefix(v string) predicate.Resources

DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.

func DescriptionHasSuffix

func DescriptionHasSuffix(v string) predicate.Resources

DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.

func DescriptionIn

func DescriptionIn(vs ...string) predicate.Resources

DescriptionIn applies the In predicate on the "description" field.

func DescriptionLT

func DescriptionLT(v string) predicate.Resources

DescriptionLT applies the LT predicate on the "description" field.

func DescriptionLTE

func DescriptionLTE(v string) predicate.Resources

DescriptionLTE applies the LTE predicate on the "description" field.

func DescriptionNEQ

func DescriptionNEQ(v string) predicate.Resources

DescriptionNEQ applies the NEQ predicate on the "description" field.

func DescriptionNotIn

func DescriptionNotIn(vs ...string) predicate.Resources

DescriptionNotIn applies the NotIn predicate on the "description" field.

func Enabled

func Enabled(v bool) predicate.Resources

Enabled applies equality check predicate on the "enabled" field. It's identical to EnabledEQ.

func EnabledEQ

func EnabledEQ(v bool) predicate.Resources

EnabledEQ applies the EQ predicate on the "enabled" field.

func EnabledNEQ

func EnabledNEQ(v bool) predicate.Resources

EnabledNEQ applies the NEQ predicate on the "enabled" field.

func HasLionPermissions

func HasLionPermissions() predicate.Resources

HasLionPermissions applies the HasEdge predicate on the "lion_permissions" edge.

func HasLionPermissionsWith

func HasLionPermissionsWith(preds ...predicate.Permissions) predicate.Resources

HasLionPermissionsWith applies the HasEdge predicate on the "lion_permissions" edge with a given conditions (other predicates).

func Hidden

func Hidden(v bool) predicate.Resources

Hidden applies equality check predicate on the "hidden" field. It's identical to HiddenEQ.

func HiddenEQ

func HiddenEQ(v bool) predicate.Resources

HiddenEQ applies the EQ predicate on the "hidden" field.

func HiddenNEQ

func HiddenNEQ(v bool) predicate.Resources

HiddenNEQ applies the NEQ predicate on the "hidden" field.

func HideChildren

func HideChildren(v bool) predicate.Resources

HideChildren applies equality check predicate on the "hide_children" field. It's identical to HideChildrenEQ.

func HideChildrenEQ

func HideChildrenEQ(v bool) predicate.Resources

HideChildrenEQ applies the EQ predicate on the "hide_children" field.

func HideChildrenNEQ

func HideChildrenNEQ(v bool) predicate.Resources

HideChildrenNEQ applies the NEQ predicate on the "hide_children" field.

func ID

func ID(id int) predicate.Resources

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Resources

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Resources

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Resources

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Resources

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Resources

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Resources

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Resources

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Resources

IDNotIn applies the NotIn predicate on the ID field.

func Icon

func Icon(v string) predicate.Resources

Icon applies equality check predicate on the "icon" field. It's identical to IconEQ.

func IconContains

func IconContains(v string) predicate.Resources

IconContains applies the Contains predicate on the "icon" field.

func IconContainsFold

func IconContainsFold(v string) predicate.Resources

IconContainsFold applies the ContainsFold predicate on the "icon" field.

func IconEQ

func IconEQ(v string) predicate.Resources

IconEQ applies the EQ predicate on the "icon" field.

func IconEqualFold

func IconEqualFold(v string) predicate.Resources

IconEqualFold applies the EqualFold predicate on the "icon" field.

func IconGT

func IconGT(v string) predicate.Resources

IconGT applies the GT predicate on the "icon" field.

func IconGTE

func IconGTE(v string) predicate.Resources

IconGTE applies the GTE predicate on the "icon" field.

func IconHasPrefix

func IconHasPrefix(v string) predicate.Resources

IconHasPrefix applies the HasPrefix predicate on the "icon" field.

func IconHasSuffix

func IconHasSuffix(v string) predicate.Resources

IconHasSuffix applies the HasSuffix predicate on the "icon" field.

func IconIn

func IconIn(vs ...string) predicate.Resources

IconIn applies the In predicate on the "icon" field.

func IconLT

func IconLT(v string) predicate.Resources

IconLT applies the LT predicate on the "icon" field.

func IconLTE

func IconLTE(v string) predicate.Resources

IconLTE applies the LTE predicate on the "icon" field.

func IconNEQ

func IconNEQ(v string) predicate.Resources

IconNEQ applies the NEQ predicate on the "icon" field.

func IconNotIn

func IconNotIn(vs ...string) predicate.Resources

IconNotIn applies the NotIn predicate on the "icon" field.

func Name

func Name(v string) predicate.Resources

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Resources

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Resources

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Resources

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Resources

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Resources

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Resources

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Resources

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Resources

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Resources

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Resources

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Resources

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Resources

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Resources

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Resources) predicate.Resources

Or groups predicates with the OR operator between them.

func ParentID

func ParentID(v int) predicate.Resources

ParentID applies equality check predicate on the "parent_id" field. It's identical to ParentIDEQ.

func ParentIDEQ

func ParentIDEQ(v int) predicate.Resources

ParentIDEQ applies the EQ predicate on the "parent_id" field.

func ParentIDGT

func ParentIDGT(v int) predicate.Resources

ParentIDGT applies the GT predicate on the "parent_id" field.

func ParentIDGTE

func ParentIDGTE(v int) predicate.Resources

ParentIDGTE applies the GTE predicate on the "parent_id" field.

func ParentIDIn

func ParentIDIn(vs ...int) predicate.Resources

ParentIDIn applies the In predicate on the "parent_id" field.

func ParentIDLT

func ParentIDLT(v int) predicate.Resources

ParentIDLT applies the LT predicate on the "parent_id" field.

func ParentIDLTE

func ParentIDLTE(v int) predicate.Resources

ParentIDLTE applies the LTE predicate on the "parent_id" field.

func ParentIDNEQ

func ParentIDNEQ(v int) predicate.Resources

ParentIDNEQ applies the NEQ predicate on the "parent_id" field.

func ParentIDNotIn

func ParentIDNotIn(vs ...int) predicate.Resources

ParentIDNotIn applies the NotIn predicate on the "parent_id" field.

func Path

func Path(v string) predicate.Resources

Path applies equality check predicate on the "path" field. It's identical to PathEQ.

func PathContains

func PathContains(v string) predicate.Resources

PathContains applies the Contains predicate on the "path" field.

func PathContainsFold

func PathContainsFold(v string) predicate.Resources

PathContainsFold applies the ContainsFold predicate on the "path" field.

func PathEQ

func PathEQ(v string) predicate.Resources

PathEQ applies the EQ predicate on the "path" field.

func PathEqualFold

func PathEqualFold(v string) predicate.Resources

PathEqualFold applies the EqualFold predicate on the "path" field.

func PathGT

func PathGT(v string) predicate.Resources

PathGT applies the GT predicate on the "path" field.

func PathGTE

func PathGTE(v string) predicate.Resources

PathGTE applies the GTE predicate on the "path" field.

func PathHasPrefix

func PathHasPrefix(v string) predicate.Resources

PathHasPrefix applies the HasPrefix predicate on the "path" field.

func PathHasSuffix

func PathHasSuffix(v string) predicate.Resources

PathHasSuffix applies the HasSuffix predicate on the "path" field.

func PathIn

func PathIn(vs ...string) predicate.Resources

PathIn applies the In predicate on the "path" field.

func PathLT

func PathLT(v string) predicate.Resources

PathLT applies the LT predicate on the "path" field.

func PathLTE

func PathLTE(v string) predicate.Resources

PathLTE applies the LTE predicate on the "path" field.

func PathNEQ

func PathNEQ(v string) predicate.Resources

PathNEQ applies the NEQ predicate on the "path" field.

func PathNotIn

func PathNotIn(vs ...string) predicate.Resources

PathNotIn applies the NotIn predicate on the "path" field.

func ResourceScope

func ResourceScope(v int) predicate.Resources

ResourceScope applies equality check predicate on the "resource_scope" field. It's identical to ResourceScopeEQ.

func ResourceScopeEQ

func ResourceScopeEQ(v int) predicate.Resources

ResourceScopeEQ applies the EQ predicate on the "resource_scope" field.

func ResourceScopeGT

func ResourceScopeGT(v int) predicate.Resources

ResourceScopeGT applies the GT predicate on the "resource_scope" field.

func ResourceScopeGTE

func ResourceScopeGTE(v int) predicate.Resources

ResourceScopeGTE applies the GTE predicate on the "resource_scope" field.

func ResourceScopeIn

func ResourceScopeIn(vs ...int) predicate.Resources

ResourceScopeIn applies the In predicate on the "resource_scope" field.

func ResourceScopeLT

func ResourceScopeLT(v int) predicate.Resources

ResourceScopeLT applies the LT predicate on the "resource_scope" field.

func ResourceScopeLTE

func ResourceScopeLTE(v int) predicate.Resources

ResourceScopeLTE applies the LTE predicate on the "resource_scope" field.

func ResourceScopeNEQ

func ResourceScopeNEQ(v int) predicate.Resources

ResourceScopeNEQ applies the NEQ predicate on the "resource_scope" field.

func ResourceScopeNotIn

func ResourceScopeNotIn(vs ...int) predicate.Resources

ResourceScopeNotIn applies the NotIn predicate on the "resource_scope" field.

func ResourceType

func ResourceType(v int) predicate.Resources

ResourceType applies equality check predicate on the "resource_type" field. It's identical to ResourceTypeEQ.

func ResourceTypeEQ

func ResourceTypeEQ(v int) predicate.Resources

ResourceTypeEQ applies the EQ predicate on the "resource_type" field.

func ResourceTypeGT

func ResourceTypeGT(v int) predicate.Resources

ResourceTypeGT applies the GT predicate on the "resource_type" field.

func ResourceTypeGTE

func ResourceTypeGTE(v int) predicate.Resources

ResourceTypeGTE applies the GTE predicate on the "resource_type" field.

func ResourceTypeIn

func ResourceTypeIn(vs ...int) predicate.Resources

ResourceTypeIn applies the In predicate on the "resource_type" field.

func ResourceTypeLT

func ResourceTypeLT(v int) predicate.Resources

ResourceTypeLT applies the LT predicate on the "resource_type" field.

func ResourceTypeLTE

func ResourceTypeLTE(v int) predicate.Resources

ResourceTypeLTE applies the LTE predicate on the "resource_type" field.

func ResourceTypeNEQ

func ResourceTypeNEQ(v int) predicate.Resources

ResourceTypeNEQ applies the NEQ predicate on the "resource_type" field.

func ResourceTypeNotIn

func ResourceTypeNotIn(vs ...int) predicate.Resources

ResourceTypeNotIn applies the NotIn predicate on the "resource_type" field.

func SortOrder

func SortOrder(v int) predicate.Resources

SortOrder applies equality check predicate on the "sort_order" field. It's identical to SortOrderEQ.

func SortOrderEQ

func SortOrderEQ(v int) predicate.Resources

SortOrderEQ applies the EQ predicate on the "sort_order" field.

func SortOrderGT

func SortOrderGT(v int) predicate.Resources

SortOrderGT applies the GT predicate on the "sort_order" field.

func SortOrderGTE

func SortOrderGTE(v int) predicate.Resources

SortOrderGTE applies the GTE predicate on the "sort_order" field.

func SortOrderIn

func SortOrderIn(vs ...int) predicate.Resources

SortOrderIn applies the In predicate on the "sort_order" field.

func SortOrderLT

func SortOrderLT(v int) predicate.Resources

SortOrderLT applies the LT predicate on the "sort_order" field.

func SortOrderLTE

func SortOrderLTE(v int) predicate.Resources

SortOrderLTE applies the LTE predicate on the "sort_order" field.

func SortOrderNEQ

func SortOrderNEQ(v int) predicate.Resources

SortOrderNEQ applies the NEQ predicate on the "sort_order" field.

func SortOrderNotIn

func SortOrderNotIn(vs ...int) predicate.Resources

SortOrderNotIn applies the NotIn predicate on the "sort_order" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Resources

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Resources

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Resources

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Resources

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Resources

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Resources

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Resources

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Resources

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Resources

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedBy

func UpdatedBy(v int64) predicate.Resources

UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.

func UpdatedByEQ

func UpdatedByEQ(v int64) predicate.Resources

UpdatedByEQ applies the EQ predicate on the "updated_by" field.

func UpdatedByGT

func UpdatedByGT(v int64) predicate.Resources

UpdatedByGT applies the GT predicate on the "updated_by" field.

func UpdatedByGTE

func UpdatedByGTE(v int64) predicate.Resources

UpdatedByGTE applies the GTE predicate on the "updated_by" field.

func UpdatedByIn

func UpdatedByIn(vs ...int64) predicate.Resources

UpdatedByIn applies the In predicate on the "updated_by" field.

func UpdatedByIsNil

func UpdatedByIsNil() predicate.Resources

UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.

func UpdatedByLT

func UpdatedByLT(v int64) predicate.Resources

UpdatedByLT applies the LT predicate on the "updated_by" field.

func UpdatedByLTE

func UpdatedByLTE(v int64) predicate.Resources

UpdatedByLTE applies the LTE predicate on the "updated_by" field.

func UpdatedByNEQ

func UpdatedByNEQ(v int64) predicate.Resources

UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.

func UpdatedByNotIn

func UpdatedByNotIn(vs ...int64) predicate.Resources

UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.

func UpdatedByNotNil

func UpdatedByNotNil() predicate.Resources

UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Resources queries.

func ByComponent

func ByComponent(opts ...sql.OrderTermOption) OrderOption

ByComponent orders the results by the component field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedBy

func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption

ByCreatedBy orders the results by the created_by field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDescription

func ByDescription(opts ...sql.OrderTermOption) OrderOption

ByDescription orders the results by the description field.

func ByEnabled

func ByEnabled(opts ...sql.OrderTermOption) OrderOption

ByEnabled orders the results by the enabled field.

func ByHidden

func ByHidden(opts ...sql.OrderTermOption) OrderOption

ByHidden orders the results by the hidden field.

func ByHideChildren

func ByHideChildren(opts ...sql.OrderTermOption) OrderOption

ByHideChildren orders the results by the hide_children field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIcon

func ByIcon(opts ...sql.OrderTermOption) OrderOption

ByIcon orders the results by the icon field.

func ByLionPermissions

func ByLionPermissions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByLionPermissions orders the results by lion_permissions terms.

func ByLionPermissionsCount

func ByLionPermissionsCount(opts ...sql.OrderTermOption) OrderOption

ByLionPermissionsCount orders the results by lion_permissions count.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByParentID

func ByParentID(opts ...sql.OrderTermOption) OrderOption

ByParentID orders the results by the parent_id field.

func ByPath

func ByPath(opts ...sql.OrderTermOption) OrderOption

ByPath orders the results by the path field.

func ByResourceScope

func ByResourceScope(opts ...sql.OrderTermOption) OrderOption

ByResourceScope orders the results by the resource_scope field.

func ByResourceType

func ByResourceType(opts ...sql.OrderTermOption) OrderOption

ByResourceType orders the results by the resource_type field.

func BySortOrder

func BySortOrder(opts ...sql.OrderTermOption) OrderOption

BySortOrder orders the results by the sort_order field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedBy

func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption

ByUpdatedBy orders the results by the updated_by field.

Jump to