userprofiles

package
v0.3.9-beta.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 17, 2025 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the userprofiles type in the database.
	Label = "user_profiles"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// FieldAttrKey holds the string denoting the attr_key field in the database.
	FieldAttrKey = "attr_key"
	// FieldAttrValue holds the string denoting the attr_value field in the database.
	FieldAttrValue = "attr_value"
	// Table holds the table name of the userprofiles in the database.
	Table = "lion_user_profiles"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// UserIDValidator is a validator for the "user_id" field. It is called by the builders before save.
	UserIDValidator func(int) error
	// AttrKeyValidator is a validator for the "attr_key" field. It is called by the builders before save.
	AttrKeyValidator func(string) error
	// AttrValueValidator is a validator for the "attr_value" field. It is called by the builders before save.
	AttrValueValidator func(string) error
)

Columns holds all SQL columns for userprofiles fields.

Functions

func And

func And(predicates ...predicate.UserProfiles) predicate.UserProfiles

And groups predicates with the AND operator between them.

func AttrKey

func AttrKey(v string) predicate.UserProfiles

AttrKey applies equality check predicate on the "attr_key" field. It's identical to AttrKeyEQ.

func AttrKeyContains

func AttrKeyContains(v string) predicate.UserProfiles

AttrKeyContains applies the Contains predicate on the "attr_key" field.

func AttrKeyContainsFold

func AttrKeyContainsFold(v string) predicate.UserProfiles

AttrKeyContainsFold applies the ContainsFold predicate on the "attr_key" field.

func AttrKeyEQ

func AttrKeyEQ(v string) predicate.UserProfiles

AttrKeyEQ applies the EQ predicate on the "attr_key" field.

func AttrKeyEqualFold

func AttrKeyEqualFold(v string) predicate.UserProfiles

AttrKeyEqualFold applies the EqualFold predicate on the "attr_key" field.

func AttrKeyGT

func AttrKeyGT(v string) predicate.UserProfiles

AttrKeyGT applies the GT predicate on the "attr_key" field.

func AttrKeyGTE

func AttrKeyGTE(v string) predicate.UserProfiles

AttrKeyGTE applies the GTE predicate on the "attr_key" field.

func AttrKeyHasPrefix

func AttrKeyHasPrefix(v string) predicate.UserProfiles

AttrKeyHasPrefix applies the HasPrefix predicate on the "attr_key" field.

func AttrKeyHasSuffix

func AttrKeyHasSuffix(v string) predicate.UserProfiles

AttrKeyHasSuffix applies the HasSuffix predicate on the "attr_key" field.

func AttrKeyIn

func AttrKeyIn(vs ...string) predicate.UserProfiles

AttrKeyIn applies the In predicate on the "attr_key" field.

func AttrKeyLT

func AttrKeyLT(v string) predicate.UserProfiles

AttrKeyLT applies the LT predicate on the "attr_key" field.

func AttrKeyLTE

func AttrKeyLTE(v string) predicate.UserProfiles

AttrKeyLTE applies the LTE predicate on the "attr_key" field.

func AttrKeyNEQ

func AttrKeyNEQ(v string) predicate.UserProfiles

AttrKeyNEQ applies the NEQ predicate on the "attr_key" field.

func AttrKeyNotIn

func AttrKeyNotIn(vs ...string) predicate.UserProfiles

AttrKeyNotIn applies the NotIn predicate on the "attr_key" field.

func AttrValue

func AttrValue(v string) predicate.UserProfiles

AttrValue applies equality check predicate on the "attr_value" field. It's identical to AttrValueEQ.

func AttrValueContains

func AttrValueContains(v string) predicate.UserProfiles

AttrValueContains applies the Contains predicate on the "attr_value" field.

func AttrValueContainsFold

func AttrValueContainsFold(v string) predicate.UserProfiles

AttrValueContainsFold applies the ContainsFold predicate on the "attr_value" field.

func AttrValueEQ

func AttrValueEQ(v string) predicate.UserProfiles

AttrValueEQ applies the EQ predicate on the "attr_value" field.

func AttrValueEqualFold

func AttrValueEqualFold(v string) predicate.UserProfiles

AttrValueEqualFold applies the EqualFold predicate on the "attr_value" field.

func AttrValueGT

func AttrValueGT(v string) predicate.UserProfiles

AttrValueGT applies the GT predicate on the "attr_value" field.

func AttrValueGTE

func AttrValueGTE(v string) predicate.UserProfiles

AttrValueGTE applies the GTE predicate on the "attr_value" field.

func AttrValueHasPrefix

func AttrValueHasPrefix(v string) predicate.UserProfiles

AttrValueHasPrefix applies the HasPrefix predicate on the "attr_value" field.

func AttrValueHasSuffix

func AttrValueHasSuffix(v string) predicate.UserProfiles

AttrValueHasSuffix applies the HasSuffix predicate on the "attr_value" field.

func AttrValueIn

func AttrValueIn(vs ...string) predicate.UserProfiles

AttrValueIn applies the In predicate on the "attr_value" field.

func AttrValueLT

func AttrValueLT(v string) predicate.UserProfiles

AttrValueLT applies the LT predicate on the "attr_value" field.

func AttrValueLTE

func AttrValueLTE(v string) predicate.UserProfiles

AttrValueLTE applies the LTE predicate on the "attr_value" field.

func AttrValueNEQ

func AttrValueNEQ(v string) predicate.UserProfiles

AttrValueNEQ applies the NEQ predicate on the "attr_value" field.

func AttrValueNotIn

func AttrValueNotIn(vs ...string) predicate.UserProfiles

AttrValueNotIn applies the NotIn predicate on the "attr_value" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.UserProfiles

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.UserProfiles

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.UserProfiles

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.UserProfiles

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.UserProfiles

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.UserProfiles

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.UserProfiles

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.UserProfiles

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.UserProfiles

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.UserProfiles

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.UserProfiles

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.UserProfiles

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.UserProfiles

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.UserProfiles

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.UserProfiles

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.UserProfiles

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.UserProfiles

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.UserProfiles

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.UserProfiles

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.UserProfiles

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func ID

func ID(id int) predicate.UserProfiles

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.UserProfiles

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.UserProfiles

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.UserProfiles

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.UserProfiles

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.UserProfiles

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.UserProfiles

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.UserProfiles

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.UserProfiles

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.UserProfiles) predicate.UserProfiles

Or groups predicates with the OR operator between them.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.UserProfiles

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.UserProfiles

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.UserProfiles

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.UserProfiles

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.UserProfiles

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.UserProfiles

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.UserProfiles

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.UserProfiles

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.UserProfiles

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UserID

func UserID(v int) predicate.UserProfiles

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDEQ

func UserIDEQ(v int) predicate.UserProfiles

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDGT

func UserIDGT(v int) predicate.UserProfiles

UserIDGT applies the GT predicate on the "user_id" field.

func UserIDGTE

func UserIDGTE(v int) predicate.UserProfiles

UserIDGTE applies the GTE predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...int) predicate.UserProfiles

UserIDIn applies the In predicate on the "user_id" field.

func UserIDLT

func UserIDLT(v int) predicate.UserProfiles

UserIDLT applies the LT predicate on the "user_id" field.

func UserIDLTE

func UserIDLTE(v int) predicate.UserProfiles

UserIDLTE applies the LTE predicate on the "user_id" field.

func UserIDNEQ

func UserIDNEQ(v int) predicate.UserProfiles

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...int) predicate.UserProfiles

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the UserProfiles queries.

func ByAttrKey

func ByAttrKey(opts ...sql.OrderTermOption) OrderOption

ByAttrKey orders the results by the attr_key field.

func ByAttrValue

func ByAttrValue(opts ...sql.OrderTermOption) OrderOption

ByAttrValue orders the results by the attr_value field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

Jump to